@@ -1,6 +1,7 @@
 import psycopg2
 from abc import ABCMeta
 
+
 SCHEMA = 'schema'
 TABLE_NAME = 'table_name'
 
@@ -211,8 +212,8 @@ class ViewsQuery(QueryBase):
     base_query = """SELECT
         OWNER,
         VIEW_NAME,
-        TEXT,
-        TEXT_VC
+        TEXT
+        -- TEXT_VC
     FROM ALL_VIEWS
     WHERE 1=1
     {filters}
